#auth: SmartBoyMuzaffar

#Full Name: Muzaffar Sharofiddinov

#Description:

This is a very simple calculator.


Usage: 


    from calculator import calc



    #there t = character, num1 = 1-number, num2 = 2-number


    calc("*", 779, 223)
    
    